@@ -76,11 +76,12 @@ class FauxFactory(object):
 
         Valid values for ``str_type`` are as follows:
 
-        * alphanumeric
         * alpha
+        * alphanumeric
+        * cjk
+        * html
         * latin1
         * numeric
-        * cjk
         * utf8
         """
 
@@ -99,6 +100,8 @@ class FauxFactory(object):
             return cls.generate_cjk(length)
         elif str_type == "utf8":
             return cls.generate_utf8(length)
+        elif str_type == "html":
+            return cls.generate_html(length)
         else:
             raise Exception("%s is not a supported string type." % str_type)
 
